==> WebServer-1.1.1.tar.gz: WebServer-1.1.1/testWebServer.m <==
/** 
   Copyright (C) 2005 Free Software Foundation, Inc.
   
   Written by:  Richard Frith-Macdonald <rfm@gnu.org>
   Date:	September 2005
   
   This file is part of the SQLClient Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
   
   You should have received a copy of the GNU Library General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.

   $Date: 2006-02-22 11:46:58 +0000 (Wed, 22 Feb 2006) $ $Revision: 22547 $
   */ 

#include	<Foundation/Foundation.h>
#include	<GNUstepBase/GSMime.h>
#include	"WebServer.h"

@interface	Handler: NSObject
- (BOOL) processRequest: (GSMimeDocument*)request
               response: (GSMimeDocument*)response
		    for: (WebServer*)http;
@end
@implementation	Handler
- (BOOL) processRequest: (GSMimeDocument*)request
               response: (GSMimeDocument*)response
		    for: (WebServer*)http
{
  NSString		*s;

  s = [[NSString alloc] initWithData: [request rawMimeData]
			    encoding: NSISOLatin1StringEncoding];
  NSLog(@"Got request -\n%@\n", s);
  [response setContent: s type: @"text/plain" name: nil];
  RELEASE(s);

  return YES;
}
@end

int
main()
{
  CREATE_AUTORELEASE_POOL(pool);
  WebServer		*server;
  Handler		*handler;
  NSUserDefaults	*defs;

  defs = [NSUserDefaults standardUserDefaults];
  [defs registerDefaults:
    [NSDictionary dictionaryWithObjectsAndKeys:
      @"80", @"Port",
      nil]
    ];

  server = [WebServer new];

  handler = [Handler new];
  [server setDelegate: handler];
  [server setPort: [defs stringForKey: @"Port"] secure: nil];

  [[NSRunLoop currentRunLoop] run];

  RELEASE(pool);
  return 0;
}

==> WebServer-1.2.1.tar.gz: WebServer-1.2.1/testWebServer.m <==
/** 
   Copyright (C) 2005 Free Software Foundation, Inc.
   
   Written by:  Richard Frith-Macdonald <rfm@gnu.org>
   Date:	September 2005
   
   This file is part of the SQLClient Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 3 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.

   $Date: 2007-09-14 13:54:55 +0100 (Fri, 14 Sep 2007) $ $Revision: 25485 $
   */ 

#include	<Foundation/Foundation.h>
#include	<GNUstepBase/GSMime.h>
#include	"WebServer.h"

@interface	Handler: NSObject
- (BOOL) processRequest: (GSMimeDocument*)request
               response: (GSMimeDocument*)response
		    for: (WebServer*)http;
@end
@implementation	Handler
- (BOOL) processRequest: (GSMimeDocument*)request
               response: (GSMimeDocument*)response
		    for: (WebServer*)http
{
  NSString		*s;

  s = [[NSString alloc] initWithData: [request rawMimeData]
			    encoding: NSISOLatin1StringEncoding];
  NSLog(@"Got request -\n%@\n", s);
  [response setContent: s type: @"text/plain" name: nil];
  RELEASE(s);

  return YES;
}
@end

int
main()
{
  CREATE_AUTORELEASE_POOL(pool);
  WebServer		*server;
  Handler		*handler;
  NSUserDefaults	*defs;

  defs = [NSUserDefaults standardUserDefaults];
  [defs registerDefaults:
    [NSDictionary dictionaryWithObjectsAndKeys:
      @"80", @"Port",
      nil]
    ];

  server = [WebServer new];

  handler = [Handler new];
  [server setDelegate: handler];
  [server setPort: [defs stringForKey: @"Port"] secure: nil];

  [[NSRunLoop currentRunLoop] run];

  RELEASE(pool);
  return 0;
}
